%% Principle of Superposition

%% Linear System
% ODE:  dy/dt + 2y = 4u
sys = tf(4,[1 2]);


%% Scaling Property

% Time vector for simulation
Nt = 100;
Tfinal = 5;
t = linspace(0,Tfinal,Nt)';

% Response 1
u1 = ones(Nt,1);
y0 = 0;
[y1,t1]=lsim(sys,u1,t,y0);

% Scaling: Response to 2*u1 is the same as 2*y1
[yS,tS]=lsim(sys,2*u1,t,y0);

% Plot Results
figure(1);
plot(t1,y1,'b-.',tS,yS,'r');
xlabel('Time (sec)')
ylabel('Response, y')
legend('y_1:=Response to u_1','y_S:=Response to 2*u_1',...
    'Location','SouthEast');
grid on;
set(gca, 'LooseInset', get(gca, 'TightInset'));

if exist('garyfyFigure','file') && exist('myprint','file')
    % Code to clean up and save figure.
    % These functions are not in the standard Matlab release.
    garyfyFigure
    myprint(1,'SuperpositionScale')
end


%% Additive Property

% Response 2
u2 = sin(3*t);
[y2,t2]=lsim(sys,u2,t,y0);

% Additive: Response to u1+u2 is the same as y1+y2
[yA,tA]=lsim(sys,u1+u2,t,y0);

% Plot Results
figure(2);
plot(t1,y1,'b-.',t2,y2,'b:',tA,yA,'r');
xlabel('Time (sec)')
ylabel('Response, y')
legend('y_1:=Response to u_1','y_2:=Response to u_2',...
    'y_A:=Response to u_1+u_2','Location','SouthEast');
grid on;
set(gca, 'LooseInset', get(gca, 'TightInset'));

if exist('garyfyFigure','file') && exist('myprint','file')
    % Code to clean up and save figure.
    % These functions are not in the standard Matlab release.
    garyfyFigure
    myprint(2,'SuperpositionAdd')
end




