%% RLCPlot

%% System Parameters
R = 10;   % Ohms
L = 0.01;   % Henrys
C = 2e-4;   % Farads

%% Input and ICs
vC0 = 1;    % Volts
i0 = -1;     % Amps
IC = [vC0; i0/C];

Tf = 0.05;
Nt = 200;
t = linspace(0,Tf,Nt);
vI = sin(200*t);

%% Linear ODE
%   LC vcdd + RC vc + vc = vI
% Put in state-space form with x=[vc; vcd]

%sysTF = tf(1,[L*C R*C 1])
Asys = [0 1;-1/L/C -R/L];
Bsys = [0; 1/L/C];
Csys = [1 0];
sys = ss(Asys,Bsys,Csys,0);
damp(sys)

%% System Response
[y,t]=lsim(sys,vI,t,IC);

%% Plot Results
figure(1);

plot(t,y);
xlabel('Time (sec)')
ylabel('v_C (V)')
grid on;
set(gca, 'LooseInset', get(gca, 'TightInset'));

if exist('garyfyFigure','file') && exist('myprint','file')
    % Code to clean up and save figure.
    % These functions are not in the standard Matlab release.
    garyfyFigure
    myprint(1,'RLCPlot')
end

